@@ -1,13 +1,15 @@
+from pathlib import Path
+
 import nox
 
 
-@nox.session(python=['3.10'])
+@nox.session(python=['3.7', '3.8', '3.9', '3.10'])
 def test(session):
     session.install('.[test,toml]', 'coverage')
     session.run('coverage', 'run', '-p', '-m', 'ward', *session.posargs)
 
 
-@nox.session(python=['3.10'])
+@nox.session(python=['3.7', '3.8', '3.9', '3.10'])
 def test_without_toml(session):
     session.install('.[test-without-toml]', 'coverage')
     session.run('coverage', 'run', '-p', '-m', 'ward', *session.posargs)
@@ -27,6 +29,14 @@ def fmt(session):
         session.run(tool, '.')
 
 
+@nox.session(python=['3.10'])
+def render_readme(session):
+    with session.chdir('doc'):
+        session.install('-r', 'doc-requirements.txt')
+    content = session.run('wheezy.template', 'templates/README.md.wz', silent=True)
+    Path('README.md').write_text(content)
+
+
 @nox.session(python=['3.10'])
 def lock(session):
     session.install('pip-tools')
@@ -37,15 +47,18 @@ def lock(session):
         'test/test-without-toml-requirements.in',
         'fmt-requirements.in',
         'dev-requirements.in',
+        'doc/doc-requirements.in',
     ):
-        session.run(
-            'pip-compile',
-            '--upgrade',
-            '--no-header',
-            '--annotation-style=line',
-            '--strip-extras',
-            '--allow-unsafe',
-            '--resolver=backtracking',
-            reqsfile,
-        )
+        rf = Path.cwd() / reqsfile
+        with session.chdir(rf.parent):
+            session.run(
+                'pip-compile',
+                '--upgrade',
+                '--no-header',
+                '--annotation-style=line',
+                '--strip-extras',
+                '--allow-unsafe',
+                '--resolver=backtracking',
+                rf.name,
+            )
     session.run('zsh', '-c', '. ./.zpy/zpy.plugin.zsh; pypc -y', external=True)
